@@ -103,13 +103,13 @@ class Process(utils.AutoHandle):
             xtype = windows.remotectypes.transform_type_to_remote64bits(PROCESS_BASIC_INFORMATION)
             # Fuck-it <3
             data = (ctypes.c_char * ctypes.sizeof(xtype))()
-            windows.syswow64.NtQueryInformationProcess_32_to_64(self.handle, ProcessInformation=data, ProcessInformationLength=ctypes.sizeof(xtype))
+            windows.syswow64.NtQueryInformationProcess_32_to_64(self.limited_handle, ProcessInformation=data, ProcessInformationLength=ctypes.sizeof(xtype))
             # Map a remote64bits(PROCESS_BASIC_INFORMATION) at the address of 'data'
             x = xtype(ctypes.addressof(data), windows.current_process)
         else:
             information_type = 0
             x = PROCESS_BASIC_INFORMATION()
-            winproxy.NtQueryInformationProcess(self.handle, information_type, x)
+            winproxy.NtQueryInformationProcess(self.limited_handle, information_type, x)
         return x.InheritedFromUniqueProcessId
 
     @property
@@ -348,13 +348,13 @@ class Process(utils.AutoHandle):
         for i in itertools.count():
             try:
                 x = self.read_memory(addr + readden, read_size)
-            except winproxy.WinproxyError as e:
+            except WindowsError as e:
                 if read_size == 2:
                     raise
                 # handle read_wstring at end of page
                 # Of read failed: read only the half of size
                 # read_size must remain a multiple of 2
-                read_size = read_size / 2
+                read_size = read_size // 2
                 continue
             readden += read_size
             if b"\x00" in x:
@@ -372,13 +372,13 @@ class Process(utils.AutoHandle):
         while True:
             try:
                 x = self.read_memory(addr + readden, read_size)
-            except winproxy.WinproxyError as e:
+            except WindowsError as e:
                 if read_size == 2:
                     raise
                 # handle read_wstring at end of page
                 # Of read failed: read only the half of size
                 # read_size must remain a multiple of 2
-                read_size = int(read_size / 2)
+                read_size = read_size // 2
                 continue
             readden += read_size
             # Bytearray will work on py2 & py3
@@ -387,10 +387,10 @@ class Process(utils.AutoHandle):
             utf16_chars = [bytearray(c) for c in zip(*[iter(x)] * 2)]
             if b"\x00\x00" in utf16_chars:
                 # Translate bytearray to str/bytes for both py2 & py3
-                res.extend(bytes(x) for x in utf16_chars[:utf16_chars.index(b"\x00\x00")])
+                res.extend(x[:utf16_chars.index(b"\x00\x00") * 2])
                 break
             res.extend(x)
-        return b"".join(res).decode('utf16')
+        return bytearray(res).decode("utf-16")
 
     def write_byte(self, addr, byte):
         """write a byte at ``addr``"""
@@ -730,7 +730,13 @@ class CurrentProcess(Process):
             raise ValueError("Not a syswow process")
         return windows.syswow64.get_current_process_syswow_peb()
 
-    # TODO: use ctypes.string_ad / ctypes.wstring_at for read_string / read_wstring ?
+    # TODO: use ctypes.string_at / ctypes.wstring_at for read_string / read_wstring ?
+
+    def read_string(self, addr):
+        return ctypes.string_at(addr) # Raises WindowsError on fail
+
+    def read_wstring(self, addr):
+        return ctypes.wstring_at(addr) # Raises WindowsError on fail
 
 class WinThread(Thread):
     """Represent a thread """
@@ -981,7 +987,7 @@ class WinProcess(Process):
         :type: :class:`str`
 		"""
         buffer = ctypes.c_buffer(0x1024)
-        rsize = winproxy.GetProcessImageFileNameA(self.limited_handle, buffer)
+        rsize = winproxy.GetProcessImageFileNameA(self.limited_handle, buffer) # Use a syscall and not some remote process reading
         # GetProcessImageFileNameA returns the fullpath
         return buffer[:rsize].decode().split("\\")[-1]
 
