@@ -1,5 +1,6 @@
 import ctypes
 import windows.generated_def as gdef
+import windows.pycompat
 
 from ..apiproxy import ApiProxy, NeededParameter
 from ..error import fail_on_zero, succeed_on_zero, result_is_error_code, result_is_handle, no_error_check, result_is_ntstatus
@@ -116,6 +117,16 @@ def LookupAccountSidA(lpSystemName, lpSid, lpName, cchName, lpReferencedDomainNa
 def LookupAccountSidW(lpSystemName, lpSid, lpName, cchName, lpReferencedDomainName, cchReferencedDomainName, peUse):
     return LookupAccountSidW.ctypes_function(lpSystemName, lpSid, lpName, cchName, lpReferencedDomainName, cchReferencedDomainName, peUse)
 
+
+@Advapi32Proxy()
+def LookupAccountNameA(lpSystemName, lpAccountName, Sid, cbSid, ReferencedDomainName, cchReferencedDomainName, peUse):
+    return LookupAccountNameA.ctypes_function(lpSystemName, lpAccountName, Sid, cbSid, ReferencedDomainName, cchReferencedDomainName, peUse)
+
+@Advapi32Proxy()
+def LookupAccountNameW(lpSystemName, lpAccountName, Sid, cbSid, ReferencedDomainName, cchReferencedDomainName, peUse):
+   return LookupAccountNameW.ctypes_function(lpSystemName, lpAccountName, Sid, cbSid, ReferencedDomainName, cchReferencedDomainName, peUse)
+
+
 @Advapi32Proxy()
 def CreateWellKnownSid(WellKnownSidType, DomainSid=None, pSid=None, cbSid=NeededParameter):
     return CreateWellKnownSid.ctypes_function(WellKnownSidType, DomainSid, pSid, cbSid)
@@ -360,6 +371,21 @@ def RegEnumValueA(hKey, dwIndex, lpValueName, lpcchValueName, lpReserved, lpType
 def RegEnumValueW(hKey, dwIndex, lpValueName, lpcchValueName, lpReserved, lpType, lpData, lpcbData):
     return RegEnumValueW.ctypes_function(hKey, dwIndex, lpValueName, lpcchValueName, lpReserved, lpType, lpData, lpcbData)
 
+@Advapi32Proxy(error_check=result_is_error_code)
+def RegSaveKeyA(hKey, lpFile, lpSecurityAttributes):
+    return RegSaveKeyA.ctypes_function(hKey, lpFile, lpSecurityAttributes)
+
+@Advapi32Proxy(error_check=result_is_error_code)
+def RegSaveKeyW(hKey, lpFile, lpSecurityAttributes):
+    return RegSaveKeyW.ctypes_function(hKey, lpFile, lpSecurityAttributes)
+
+@Advapi32Proxy(error_check=result_is_error_code)
+def RegSaveKeyExA(hKey, lpFile, lpSecurityAttributes, Flags):
+    return RegSaveKeyExA.ctypes_function(hKey, lpFile, lpSecurityAttributes, Flags)
+
+@Advapi32Proxy(error_check=result_is_error_code)
+def RegSaveKeyExW(hKey, lpFile, lpSecurityAttributes, Flags):
+    return RegSaveKeyExW.ctypes_function(hKey, lpFile, lpSecurityAttributes, Flags)
 
 # Service
 
@@ -479,6 +505,10 @@ def CryptDestroyKey(hKey):
 def CryptExportKey(hKey, hExpKey, dwBlobType, dwFlags, pbData, pdwDataLen):
     return CryptExportKey.ctypes_function(hKey, hExpKey, dwBlobType, dwFlags, pbData, pdwDataLen)
 
+@Advapi32Proxy()
+def CryptImportKey(hProv, pbData, dwDataLen, hPubKey, dwFlags, phKey):
+    return CryptImportKey.ctypes_function(hProv, pbData, dwDataLen, hPubKey, dwFlags, phKey)
+
 ## crypt context
 
 @Advapi32Proxy()
@@ -495,9 +525,64 @@ def CryptAcquireContextW(phProv, pszContainer, pszProvider, dwProvType, dwFlags)
 def CryptReleaseContext(hProv, dwFlags):
     return CryptReleaseContext.ctypes_function(hProv, dwFlags)
 
+## Encrypt / Decrypt
+
+@Advapi32Proxy()
+def CryptEncrypt(hKey, hHash, Final, dwFlags, pbData, pdwDataLen, dwBufLen):
+    return CryptEncrypt.ctypes_function(hKey, hHash, Final, dwFlags, pbData, pdwDataLen, dwBufLen)
+
+@Advapi32Proxy()
+def CryptDecrypt(hKey, hHash, Final, dwFlags, pbData, pdwDataLen):
+    return CryptDecrypt.ctypes_function(hKey, hHash, Final, dwFlags, pbData, pdwDataLen)
+
+## Crypt Key
+
+@Advapi32Proxy()
+def CryptDeriveKey(hProv, Algid, hBaseData, dwFlags, phKey):
+    return CryptDeriveKey.ctypes_function(hProv, Algid, hBaseData, dwFlags, phKey)
+
+## Crypt hash
+
+@Advapi32Proxy()
+def CryptCreateHash(hProv, Algid, hKey=None, dwFlags=0, phHash=NeededParameter):
+    return CryptCreateHash.ctypes_function(hProv, Algid, hKey, dwFlags, phHash)
+
+@Advapi32Proxy()
+def CryptHashData(hHash, pbData, dwDataLen=None, dwFlags=0):
+    if isinstance(pbData, windows.pycompat.anybuff):
+        pbData = (gdef.BYTE * len(pbData))(*bytearray(pbData))
+    if dwDataLen is None:
+        dwDataLen = len(pbData)
+    return CryptHashData.ctypes_function(hHash, pbData, dwDataLen, dwFlags)
+
+@Advapi32Proxy()
+def CryptGetHashParam(hHash, dwParam, pbData, pdwDataLen=None, dwFlags=0):
+    if pdwDataLen is None:
+        pdwDataLen = ctypes.sizeof(pbData)
+    return CryptGetHashParam.ctypes_function(hHash, dwParam, pbData, pdwDataLen, dwFlags)
+
+@Advapi32Proxy()
+def CryptVerifySignatureA(hHash, pbSignature, dwSigLen, hPubKey, szDescription, dwFlags):
+    return CryptVerifySignatureA.ctypes_function(hHash, pbSignature, dwSigLen, hPubKey, szDescription, dwFlags)
+
+@Advapi32Proxy()
+def CryptVerifySignatureW(hHash, pbSignature, dwSigLen, hPubKey, szDescription, dwFlags):
+    return CryptVerifySignatureW.ctypes_function(hHash, pbSignature, dwSigLen, hPubKey, szDescription, dwFlags)
+
+@Advapi32Proxy()
+def CryptSignHashA(hHash, dwKeySpec, szDescription, dwFlags, pbSignature, pdwSigLen):
+    return CryptSignHashA.ctypes_function(hHash, dwKeySpec, szDescription, dwFlags, pbSignature, pdwSigLen)
+
+@Advapi32Proxy()
+def CryptSignHashW(hHash, dwKeySpec, szDescription, dwFlags, pbSignature, pdwSigLen):
+    return CryptSignHashW.ctypes_function(hHash, dwKeySpec, szDescription, dwFlags, pbSignature, pdwSigLen)
+
+@Advapi32Proxy()
+def CryptDestroyHash(hHash):
+    return CryptDestroyHash.ctypes_function(hHash)
+
 
 ## Event Tracing
-
 @Advapi32Proxy(error_check=succeed_on_zero)
 def EnumerateTraceGuidsEx(TraceQueryInfoClass, InBuffer, InBufferSize, OutBuffer, OutBufferSize, ReturnLength):
     if isinstance(InBuffer, gdef.GUID):
