@@ -498,11 +498,21 @@ def CreateFileMappingA(hFile, lpFileMappingAttributes=None, flProtect=gdef.PAGE_
 def CreateFileMappingW(hFile, lpFileMappingAttributes=None, flProtect=gdef.PAGE_READWRITE, dwMaximumSizeHigh=0, dwMaximumSizeLow=0, lpName=NeededParameter):
     return CreateFileMappingW.ctypes_function(hFile, lpFileMappingAttributes, flProtect, dwMaximumSizeHigh, dwMaximumSizeLow, lpName)
 
+@Kernel32Proxy()
+def OpenFileMappingW(dwDesiredAccess, bInheritHandle, lpName):
+    return OpenFileMappingW.ctypes_function(dwDesiredAccess, bInheritHandle, lpName)
+
+@Kernel32Proxy()
+def OpenFileMappingA(dwDesiredAccess, bInheritHandle, lpName):
+    return OpenFileMappingA.ctypes_function(dwDesiredAccess, bInheritHandle, lpName)
 
 @Kernel32Proxy()
 def MapViewOfFile(hFileMappingObject, dwDesiredAccess=gdef.FILE_MAP_ALL_ACCESS, dwFileOffsetHigh=0, dwFileOffsetLow=0, dwNumberOfBytesToMap=NeededParameter):
     return MapViewOfFile.ctypes_function(hFileMappingObject, dwDesiredAccess, dwFileOffsetHigh, dwFileOffsetLow, dwNumberOfBytesToMap)
 
+@Kernel32Proxy()
+def UnmapViewOfFile(lpBaseAddress):
+    return UnmapViewOfFile.ctypes_function(lpBaseAddress)
 
 @Kernel32Proxy()
 def FindFirstFileA(lpFileName, lpFindFileData):
@@ -581,7 +591,23 @@ def OpenEventA(dwDesiredAccess, bInheritHandle, lpName):
 
 @Kernel32Proxy()
 def OpenEventW(dwDesiredAccess, bInheritHandle, lpName):
-    return OpenEventA.ctypes_function(dwDesiredAccess, bInheritHandle, lpName)
+    return OpenEventW.ctypes_function(dwDesiredAccess, bInheritHandle, lpName)
+
+@Kernel32Proxy()
+def CreateEventA(lpEventAttributes, bManualReset, bInitialState, lpName):
+    return CreateEventA.ctypes_function(lpEventAttributes, bManualReset, bInitialState, lpName)
+
+@Kernel32Proxy()
+def CreateEventW(lpEventAttributes, bManualReset, bInitialState, lpName):
+    return CreateEventW.ctypes_function(lpEventAttributes, bManualReset, bInitialState, lpName)
+
+@Kernel32Proxy()
+def CreateEventExA(lpEventAttributes, lpName, dwFlags, dwDesiredAccess):
+    return CreateEventExA.ctypes_function(lpEventAttributes, lpName, dwFlags, dwDesiredAccess)
+
+@Kernel32Proxy()
+def CreateEventExW(lpEventAttributes, lpName, dwFlags, dwDesiredAccess):
+    return CreateEventExW.ctypes_function(lpEventAttributes, lpName, dwFlags, dwDesiredAccess)
 
 
 ## Path
@@ -787,6 +813,22 @@ def GetSystemTimeAsFileTime(lpSystemTimeAsFileTime):
    return GetSystemTimeAsFileTime.ctypes_function(lpSystemTimeAsFileTime)
 
 
+@Kernel32Proxy(error_check=fail_on_zero)
+def GetSystemTimes(lpIdleTime, lpKernelTime, lpUserTime):
+    return GetSystemTimes.ctypes_function(lpIdleTime, lpKernelTime, lpUserTime)
+
+@Kernel32Proxy(error_check=None)
+def GetLocalTime(lpSystemTime):
+    return GetLocalTime.ctypes_function(lpSystemTime)
+
+@Kernel32Proxy(error_check=None)
+def GetTickCount():
+    return GetTickCount.ctypes_function()
+
+@Kernel32Proxy(error_check=None)
+def GetTickCount64():
+    return GetTickCount64.ctypes_function()
+
 #####
 
 # Heap
@@ -794,3 +836,48 @@ def GetSystemTimeAsFileTime(lpSystemTimeAsFileTime):
 @Kernel32Proxy(error_check=fail_on_zero)
 def HeapAlloc(hHeap, dwFlags, dwBytes):
     return HeapAlloc.ctypes_function(hHeap, dwFlags, dwBytes)
+
+
+#####
+
+# Resources
+
+@Kernel32Proxy()
+def FindResourceA(hModule, lpName, lpType):
+    return FindResourceA.ctypes_function(hModule, lpName, lpType)
+
+@Kernel32Proxy()
+def FindResourceW(hModule, lpName, lpType):
+    return FindResourceW.ctypes_function(hModule, lpName, lpType)
+
+@Kernel32Proxy()
+def SizeofResource(hModule, hResInfo):
+    return SizeofResource.ctypes_function(hModule, hResInfo)
+
+@Kernel32Proxy()
+def LoadResource(hModule, hResInfo):
+    return LoadResource.ctypes_function(hModule, hResInfo)
+
+@Kernel32Proxy()
+def LockResource(hResData):
+    return LockResource.ctypes_function(hResData)
+
+@Kernel32Proxy()
+def FreeResource(hResData):
+    return FreeResource.ctypes_function(hResData)
+
+@Kernel32Proxy()
+def EnumResourceTypesA(hModule, lpEnumFunc, lParam):
+    return EnumResourceTypesA.ctypes_function(hModule, lpEnumFunc, lParam)
+
+@Kernel32Proxy()
+def EnumResourceTypesW(hModule, lpEnumFunc, lParam):
+    return EnumResourceTypesW.ctypes_function(hModule, lpEnumFunc, lParam)
+
+@Kernel32Proxy()
+def EnumResourceNamesA(hModule, lpType, lpEnumFunc, lParam):
+    return EnumResourceNamesA.ctypes_function(hModule, lpType, lpEnumFunc, lParam)
+
+@Kernel32Proxy()
+def EnumResourceNamesW(hModule, lpType, lpEnumFunc, lParam):
+    return EnumResourceNamesW.ctypes_function(hModule, lpType, lpEnumFunc, lParam)
\ No newline at end of file
